@@ -1876,17 +1876,11 @@ class VariableClUpdateUseMigrationHost(Variable):
     type = "bool"
     value = "off"
 
-class VariableClUpdateMigrationHost(Variable):
-    """
-    Используемый хост миграции
-    """
-    value = ""
-
-class VariableClBinhostStash(Variable):
-    """
-    Бекап хоста обновления
-    """
-    value = ""
+# class VariableClUpdateMigrationHost(Variable):
+#     """
+#     Используемый хост миграции
+#     """
+#     value = ""
 
 class VariableClUpdateIgnoreLevel(Variable):
     """
@@ -1920,3 +1914,9 @@ class VariableClUpdateForceLevelMode(Variable):
     """
     type = "bool"
     value = "off"
+
+class VariableClUpdateSavedTag(Variable):
+    """
+    Сохраняемый тэг репозитория calculate
+    """
+    type = "int"
\ No newline at end of file
