@@ -71,25 +71,27 @@ class Wsdl(WsdlBase):
                                         'cl_update_with_bdeps_opt_set'
                                     ),
                                     expert=(
-                                    'cl_update_sync_only_set',
-                                    'cl_update_other_set',
-                                    'cl_update_pretend_set',
-                                    'cl_update_sync_rep',
-                                    'cl_update_emergelist_set',
-                                    'cl_update_check_rep_set',
-                                    'cl_update_force_fix_set',
-                                    'cl_update_world',
-                                    'cl_update_gpg_force',
-                                    'cl_update_egencache_force',
-                                    'cl_update_eixupdate_force',
-                                    'cl_update_revdep_rebuild_set',
-                                    'cl_update_wait_another_set',
-                                    'cl_update_autocheck_schedule_set',
-                                    'cl_update_onedepth_set',
-                                    'cl_update_cleanpkg_set',
-                                    'cl_update_branch_data',
-                                    'cl_templates_locate',
-                                    'cl_verbose_set', 'cl_dispatch_conf'),
+                                        'cl_update_sync_only_set',
+                                        'cl_update_other_set',
+                                        'cl_update_pretend_set',
+                                        'cl_update_sync_rep',
+                                        'cl_update_emergelist_set',
+                                        'cl_update_check_rep_set',
+                                        'cl_update_force_fix_set',
+                                        'cl_update_ignore_level',
+                                        'cl_update_force_level',
+                                        'cl_update_world',
+                                        'cl_update_gpg_force',
+                                        'cl_update_egencache_force',
+                                        'cl_update_eixupdate_force',
+                                        'cl_update_revdep_rebuild_set',
+                                        'cl_update_wait_another_set',
+                                        'cl_update_autocheck_schedule_set',
+                                        'cl_update_onedepth_set',
+                                        'cl_update_cleanpkg_set',
+                                        'cl_update_branch_data',
+                                        'cl_templates_locate',
+                                        'cl_verbose_set', 'cl_dispatch_conf'),
                                     next_label=_("Run"))]},
         #
         # Сменить профиль
